@@ -12,10 +12,13 @@ use strict;
 use warnings;
 
 use Kernel::System::WebUserAgent;
+use Kernel::Language qw(Translatable);
 use Text::Diff::FormattedHTML;
 use Kernel::System::VariableCheck qw(:all);
 use File::stat;
 
+use Cwd 'abs_path';
+
 our @ObjectDependencies = (
     'Kernel::Config',
     'Kernel::Language',
@@ -71,6 +74,16 @@ sub Run {
         );
     }
 
+    my $IsZnunyFile = $Self->_IsZnunyFile(
+        File => $Param{File}
+    );
+
+    if ( $Param{File} && !$IsZnunyFile ) {
+        return $LayoutObject->ErrorScreen(
+            Message => Translatable('File or Directory not found.'),
+        );
+    }
+
     if ( !$Param{File} ) {
         $LayoutObject->Block(
             Name => 'Sidebar',
@@ -698,6 +711,8 @@ sub FileDetailsExtended {
 
     my $OriginalPath = $Param{FullPath};
 
+    $Param{Type} //= 'Package';
+
     if ( $Param{Type} eq 'Package' ) {
 
         my @RepositoryList = $PackageObject->RepositoryList(
@@ -804,4 +819,20 @@ sub FileDetailsExtended {
     return %Extended;
 }
 
+sub _IsZnunyFile {
+    my ( $Self, %Param ) = @_;
+
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
+    return if !IsStringWithData( $Param{File} );
+
+    my $AbsoluteFilePath = abs_path( $Param{File} );
+
+    my $Home = $ConfigObject->Get('Home');
+
+    return if $AbsoluteFilePath !~ m{\A\Q$Home\E};
+
+    return 1;
+}
+
 1;
