@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -46,20 +46,9 @@ sub new {
     my $Self = {%Param};
     bless( $Self, $Type );
 
-    $Self->{TimeZonesMap} = {
-        'Pacific Standard Time'   => 'PST8PDT',
-        'W. Europe Standard Time' => 'WET',
-        'Mountain Standard Time'  => 'MST7MDT',
-        'Central Standard Time'   => 'CST6CDT',
-        'Eastern Standard Time'   => 'EST5EDT',
-        'Etc/GMT+10'              => 'HST',
-        'Etc/GMT+5'               => 'EST',
-        'Etc/GMT+7'               => 'MST',
-        'ROK'                     => 'Asia/Seoul',
-        'ROC'                     => 'Asia/Taipei',
-        'Cuba'                    => 'America/Havana',
-        'Jamaica'                 => 'America/Jamaica',
-    };
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
+    $Self->{TimeZonesMap} = $ConfigObject->Get('AppointmentCalendar::NonStandardTimeZonesMapping') // {};
 
     $Self->{GlobalPropertiesMap} = {
         Events => {
@@ -121,7 +110,8 @@ Parses ICS string.
 sub Parse {
     my ( $Self, %Param ) = @_;
 
-    my $LogObject = $Kernel::OM->Get('Kernel::System::Log');
+    my $LogObject    = $Kernel::OM->Get('Kernel::System::Log');
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
 
     NEEDED:
     for my $Needed (qw(String)) {
@@ -147,20 +137,29 @@ sub Parse {
 
     # parser accepts only timezones from TimeZoneList()
     # any other format will result in error
-    my $TimeZones = Kernel::System::DateTime->TimeZoneList();
+    my $TimeZones = Kernel::System::DateTime->TimeZoneList() // [];
+    my %TimeZones = map { $_ => 1 } @{$TimeZones};
 
-    if ( !grep { $_ eq $TimeZone } @{$TimeZones} ) {
+    if ( !$TimeZones{$TimeZone} ) {
         $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
-            Message  => "Specified timezone: $TimeZone is not supported!"
+            Message  => "Specified timezone $TimeZone is not supported!"
         );
         return;
     }
 
+    my $ICSParserStartDate = $ConfigObject->Get('ICSParser::StartDate') // '20100101';
+
+    my $ICSParserEndDateObject = $Kernel::OM->Create('Kernel::System::DateTime');
+    $ICSParserEndDateObject->Add( Years => 10 );
+    my $ICSParserEndDate = $ICSParserEndDateObject->Format( Format => '%Y%m%d' );
+
     my $ParserObject;
     eval {
         $ParserObject = iCal::Parser->new(
-            tz => $TimeZone,
+            start => $ICSParserStartDate,
+            end   => $ICSParserEndDate,
+            tz    => $TimeZone,
         );
     };
     if ($@) {
