@@ -92,7 +92,7 @@ sub EditFieldRender {
     }
 
     # check and set class if necessary
-    my $FieldClass = 'DynamicFieldDropdown Modernize';
+    my $FieldClass = 'DynamicFieldText Modernize';
     if ( defined $Param{Class} && $Param{Class} ne '' ) {
         $FieldClass .= ' ' . $Param{Class};
     }
@@ -383,10 +383,12 @@ sub SearchFieldRender {
     # Assemble display values
     # If there are no available values, leave it empty.
     if ( IsHashRefWithData($SelectionData) ) {
+        my $TicketID = $Param{LayoutObject}->{TicketID};
         $SelectionData = $DynamicFieldWebserviceObject->DisplayValueGet(
             DynamicFieldConfig => $Param{DynamicFieldConfig},
             Value              => [ keys %{$SelectionData} ],
             Limit              => '',
+            TicketID           => $TicketID,
         );
     }
 
@@ -450,10 +452,12 @@ sub _AutocompleteSearchFieldRender {
 
     my $SelectionData = {};
     if ( IsArrayRefWithData($FieldValues) ) {
+        my $TicketID = $Param{LayoutObject}->{TicketID};
         $SelectionData = $DynamicFieldWebserviceObject->DisplayValueGet(
             DynamicFieldConfig => $Param{DynamicFieldConfig},
             Value              => $FieldValues,
             Limit              => '',
+            TicketID           => $TicketID,
         );
     }
 
@@ -541,9 +545,11 @@ sub ValueLookup {
 
     return $Param{Key} if !IsStringWithData( $Param{Key} );
 
-    my $Value = $DynamicFieldWebserviceObject->DisplayValueGet(
+    my $TicketID = $Param{LayoutObject}->{TicketID};
+    my $Value    = $DynamicFieldWebserviceObject->DisplayValueGet(
         DynamicFieldConfig => $Param{DynamicFieldConfig},
         Value              => $Param{Key},
+        TicketID           => $TicketID,
     );
 
     return $Value;
@@ -675,11 +681,11 @@ sub PossibleValuesGet {
 
     my %PossibleValues;
 
-    # Provide empty value if no value is present so the field will not be displayed as disabled.
-    if ( !$Param{Value} ) {
-        $PossibleValues{' '} = '';
-    }
+    # Provide empty value so the field will not be displayed as disabled if there are no selectable
+    # values yet.
+    $PossibleValues{' '} = '';
 
+    my $TicketID = $Param{LayoutObject}->{TicketID};
     if ( $Param{DynamicFieldConfig}->{Config}->{InitialSearchTerm} ) {
         my $InitialSearchTerm = $LayoutObject->Ascii2Html(
             Text => $Param{DynamicFieldConfig}->{Config}->{InitialSearchTerm},
@@ -689,6 +695,7 @@ sub PossibleValuesGet {
             DynamicFieldConfig => $Param{DynamicFieldConfig},
             SearchTerms        => $InitialSearchTerm,
             UserID             => $Param{UserID},
+            TicketID           => $TicketID,
         );
         if ( IsArrayRefWithData($Results) ) {
             for my $Result ( @{$Results} ) {
@@ -709,6 +716,7 @@ sub PossibleValuesGet {
         my $DisplayValue = $DynamicFieldWebserviceObject->DisplayValueGet(
             DynamicFieldConfig => $Param{DynamicFieldConfig},
             Value              => [ $Param{Value} ],
+            TicketID           => $TicketID,
         );
 
         %PossibleValues = (
@@ -757,4 +765,10 @@ sub StatsSearchFieldParameterBuild {
     return Kernel::System::DynamicField::Driver::BaseSelect::StatsSearchFieldParameterBuild( $Self, %Param );
 }
 
+sub FieldValueValidate {
+    my ( $Self, %Param ) = @_;
+
+    return 1;
+}
+
 1;
