@@ -158,16 +158,13 @@ sub EditFieldRender {
             $DataValues = { $Value => $Value };
         }
     }
-    elsif ( !IsHashRefWithData($DataValues) ) {
-        $DataValues = { ' ' => ' ' };
-    }
 
     my $HTMLString = $Param{LayoutObject}->BuildSelection(
         Data         => $DataValues || {},
         Name         => $FieldName,
         SelectedID   => $SelectedValuesArrayRef,
         Translation  => $FieldConfig->{TranslatableValues} || 0,
-        PossibleNone => 0,
+        PossibleNone => 1,
         TreeView     => $FieldConfig->{TreeView} || 0,
         Class        => $FieldClass,
         HTMLQuote    => 1,
@@ -546,10 +543,12 @@ sub SearchFieldRender {
     # Assemble display values
     # If there are no available values, leave it empty.
     if ( IsHashRefWithData($SelectionData) ) {
+        my $TicketID = $Param{LayoutObject}->{TicketID};
         $SelectionData = $DynamicFieldWebserviceObject->DisplayValueGet(
             DynamicFieldConfig => $Param{DynamicFieldConfig},
             Value              => [ keys %{$SelectionData} ],
             Limit              => '',
+            TicketID           => $TicketID,
         );
     }
 
@@ -558,7 +557,7 @@ sub SearchFieldRender {
         Name         => $FieldName,
         SelectedID   => $Value,
         Translation  => $FieldConfig->{TranslatableValues} || 0,
-        PossibleNone => 0,
+        PossibleNone => 1,
         TreeView     => $FieldConfig->{TreeView} || 0,
         Class        => $FieldClass,
         Multiple     => 1,
@@ -611,27 +610,24 @@ sub _AutocompleteSearchFieldRender {
     # check and set class if necessary
     my $FieldClass = 'DynamicFieldMultiSelect Modernize';
 
+    my $TicketID = $Param{LayoutObject}->{TicketID};
+
     my $SelectionData;
     if ( IsArrayRefWithData($FieldValues) ) {
         $SelectionData = $DynamicFieldWebserviceObject->DisplayValueGet(
             DynamicFieldConfig => $Param{DynamicFieldConfig},
             Value              => $FieldValues,
             Limit              => '',
+            TicketID           => $TicketID,
         );
     }
 
-    if ( !IsHashRefWithData($SelectionData) ) {
-        $SelectionData = {
-            ' ' => ' ',
-        };
-    }
-
     my $HTMLString = $Param{LayoutObject}->BuildSelection(
         Data         => $SelectionData,
         Name         => $FieldName,
         SelectedID   => $FieldValues,
         Translation  => $FieldConfig->{TranslatableValues} || 0,
-        PossibleNone => 0,
+        PossibleNone => 1,
         TreeView     => 0,
         Class        => $FieldClass,
         Multiple     => 1,
@@ -647,7 +643,6 @@ sub _AutocompleteSearchFieldRender {
 
     my $AutocompleteMinLength = int( $FieldConfig->{AutocompleteMinLength} || 3 );
     my $QueryDelay            = int( $FieldConfig->{QueryDelay}            || 1 );
-    my $TicketID              = $Param{LayoutObject}->{TicketID};
 
     if ( !IsArrayRefWithData( $FieldConfig->{AdditionalDFStorage} ) ) {
         $FieldConfig->{AdditionalDFStorage} = [];
@@ -877,16 +872,13 @@ sub PossibleValuesGet {
     my $DynamicFieldWebserviceObject = $Kernel::OM->Get('Kernel::System::DynamicField::Webservice');
     my $LayoutObject                 = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
-    # to store the possible values
     my %PossibleValues;
 
-    # set PossibleNone attribute
-    my $FieldPossibleNone = 1;
+    # Provide empty value so the field will not be displayed as disabled if there are no selectable
+    # values yet.
+    $PossibleValues{' '} = '';
 
-    # set none value if defined on field config
-    if ( $FieldPossibleNone || !$Param{Value} ) {
-        %PossibleValues = ( ' ' => '-' );
-    }
+    my $TicketID = $Param{LayoutObject}->{TicketID};
 
     if ( $Param{DynamicFieldConfig}->{Config}->{InitialSearchTerm} ) {
         my $InitialSearchTerm = $LayoutObject->Ascii2Html(
@@ -897,6 +889,7 @@ sub PossibleValuesGet {
             DynamicFieldConfig => $Param{DynamicFieldConfig},
             SearchTerms        => $InitialSearchTerm,
             UserID             => $Param{UserID},
+            TicketID           => $TicketID,
         );
         if ( IsArrayRefWithData($Results) ) {
             for my $Result ( @{$Results} ) {
@@ -917,6 +910,7 @@ sub PossibleValuesGet {
         my $DisplayValue = $DynamicFieldWebserviceObject->DisplayValueGet(
             DynamicFieldConfig => $Param{DynamicFieldConfig},
             Value              => $Param{Value},
+            TicketID           => $TicketID,
         );
 
         %PossibleValues = (
@@ -965,4 +959,10 @@ sub StatsSearchFieldParameterBuild {
     return Kernel::System::DynamicField::Driver::BaseSelect::StatsSearchFieldParameterBuild( $Self, %Param );
 }
 
+sub FieldValueValidate {
+    my ( $Self, %Param ) = @_;
+
+    return 1;
+}
+
 1;
