@@ -18,13 +18,14 @@ use Kernel::System::VariableCheck qw(:all);
 use parent qw(Kernel::System::ProcessManagement::TransitionAction::Base);
 
 our @ObjectDependencies = (
-    'Kernel::System::Log',
-    'Kernel::System::Ticket',
-    'Kernel::System::Ticket::Article',
     'Kernel::System::DynamicField',
     'Kernel::System::DynamicField::Backend',
-    'Kernel::System::User',
     'Kernel::System::HTMLUtils',
+    'Kernel::System::Log',
+    'Kernel::System::StdAttachment',
+    'Kernel::System::Ticket',
+    'Kernel::System::Ticket::Article',
+    'Kernel::System::User',
 );
 
 =head1 NAME
@@ -141,15 +142,16 @@ Returns:
             CommunicationChannel => 'Email',
 
             # Email article data payload.
-            From             => 'Some Agent <email@example.com>',
-            To               => 'Some Customer A <customer-a@example.com>',
-            Subject          => 'some short description',
-            Body             => 'the message text',
-            Charset          => 'ISO-8859-15',
-            MimeType         => 'text/plain',
-            HistoryType      => 'EmailAgent',
-            HistoryComment   => 'Some free text!',
-            UnlockOnAway     => 1,
+            From               => 'Some Agent <email@example.com>',
+            To                 => 'Some Customer A <customer-a@example.com>',
+            Subject            => 'some short description',
+            Body               => 'the message text',
+            Charset            => 'ISO-8859-15',
+            MimeType           => 'text/plain',
+            HistoryType        => 'EmailAgent',
+            HistoryComment     => 'Some free text!',
+            UnlockOnAway       => 1,
+            DynamicField_NameX => 'Value of DF Article',
         },
     );
 
@@ -196,7 +198,14 @@ Returns:
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    my $StdAttachmentObject = $Kernel::OM->Get('Kernel::System::StdAttachment');
+    my $ArticleObject             = $Kernel::OM->Get('Kernel::System::Ticket::Article');
+    my $DynamicFieldBackendObject = $Kernel::OM->Get('Kernel::System::DynamicField::Backend');
+    my $DynamicFieldObject        = $Kernel::OM->Get('Kernel::System::DynamicField');
+    my $HTMLUtilsObject           = $Kernel::OM->Get('Kernel::System::HTMLUtils');
+    my $LogObject                 = $Kernel::OM->Get('Kernel::System::Log');
+    my $StdAttachmentObject       = $Kernel::OM->Get('Kernel::System::StdAttachment');
+    my $TicketObject              = $Kernel::OM->Get('Kernel::System::Ticket');
+    my $UserObject                = $Kernel::OM->Get('Kernel::System::User');
 
     # Define a common message to output in case of any error.
     my $CommonMessage = "Process: $Param{ProcessEntityID} Activity: $Param{ActivityEntityID}"
@@ -213,7 +222,7 @@ sub Run {
     $Param{Config}->{CommunicationChannel} ||= 'Internal';
 
     if ( !defined $Param{Config}->{IsVisibleForCustomer} ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+        $LogObject->Log(
             Priority => 'error',
             Message  => "Need Config -> IsVisibleForCustomer",
         );
@@ -224,11 +233,7 @@ sub Run {
     # Override UserID if specified as a parameter in the TA config.
     $Param{UserID} = $Self->_OverrideUserID(%Param);
 
-    my $DynamicFieldObject        = $Kernel::OM->Get('Kernel::System::DynamicField');
-    my $DynamicFieldBackendObject = $Kernel::OM->Get('Kernel::System::DynamicField::Backend');
-
     # Convert DynamicField value to HTML string, see bug#14229.
-    my $HTMLUtilsObject = $Kernel::OM->Get('Kernel::System::HTMLUtils');
     if ( $Param{Config}->{Body} =~ /OTRS_TICKET_DynamicField_/ ) {
         MATCH:
         for my $Match ( sort keys %{ $Param{Ticket} } ) {
@@ -277,7 +282,7 @@ sub Run {
     {
 
         # Get current user data
-        my %User = $Kernel::OM->Get('Kernel::System::User')->GetUserData(
+        my %User = $UserObject->GetUserData(
             UserID => $Param{UserID},
         );
 
@@ -285,7 +290,7 @@ sub Run {
         $Param{Config}->{From} = $User{UserFullname} . ' <' . $User{UserEmail} . '>';
     }
 
-    my $ArticleBackendObject = $Kernel::OM->Get('Kernel::System::Ticket::Article')->BackendForChannel(
+    my $ArticleBackendObject = $ArticleObject->BackendForChannel(
         ChannelName => $Param{Config}->{CommunicationChannel}
     );
 
@@ -330,7 +335,7 @@ sub Run {
     );
 
     if ( !$ArticleID ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+        $LogObject->Log(
             Priority => 'error',
             Message  => $CommonMessage
                 . "Couldn't create article for Ticket: "
@@ -341,7 +346,7 @@ sub Run {
 
     # Set time units.
     if ( $Param{Config}->{TimeUnit} ) {
-        $Kernel::OM->Get('Kernel::System::Ticket')->TicketAccountTime(
+        $TicketObject->TicketAccountTime(
             TicketID  => $Param{Ticket}->{TicketID},
             ArticleID => $ArticleID,
             TimeUnit  => $Param{Config}->{TimeUnit},
@@ -349,6 +354,57 @@ sub Run {
         );
     }
 
+    # set dynamic fields for ticket and article
+
+    # set a field filter (all valid dynamic fields have to have set to 1 like NameX => 1)
+    my %FieldFilter;
+    for my $Attribute ( sort keys %{ $Param{Config} } ) {
+        if ( $Attribute =~ m{\A DynamicField_ ( [a-zA-Z0-9]+ ) \z}msx ) {
+            $FieldFilter{$1} = 1;
+        }
+    }
+
+    # get the dynamic fields for ticket
+    my $DynamicFieldList = $DynamicFieldObject->DynamicFieldListGet(
+        Valid       => 1,
+        ObjectType  => [ 'Ticket', 'Article' ],
+        FieldFilter => \%FieldFilter,
+    );
+
+    # cycle through the activated Dynamic Fields for this screen
+    DYNAMICFIELD:
+    for my $DynamicFieldConfig ( @{$DynamicFieldList} ) {
+        next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
+
+        my $ObjectID = $Param{Ticket}->{TicketID};
+        if ( $DynamicFieldConfig->{ObjectType} ne 'Ticket' ) {
+
+            # skip article dynamic fields if Article was not created
+            next DYNAMICFIELD if !$ArticleID;
+
+            $ObjectID = $ArticleID;
+        }
+
+        # set the value
+        my $Success = $DynamicFieldBackendObject->ValueSet(
+            DynamicFieldConfig => $DynamicFieldConfig,
+            ObjectID           => $ObjectID,
+            Value              => $Param{Config}->{ 'DynamicField_' . $DynamicFieldConfig->{Name} },
+            UserID             => $Param{UserID},
+        );
+
+        if ( !$Success ) {
+            $LogObject->Log(
+                Priority => 'error',
+                Message  => $CommonMessage
+                    . "Couldn't set DynamicField Value on $DynamicFieldConfig->{ObjectType}:"
+                    . " $ObjectID from Ticket: "
+                    . $Param{Ticket}->{TicketID} . '!',
+            );
+            return;
+        }
+    }
+
     return 1;
 }
 
