@@ -1082,8 +1082,8 @@ update queue attributes
         UserID              => 123,
         FollowUpID          => 1,
         Comment             => 'Some Comment2',
-        DefaultSignKey      => ''
-        UnlockTimeOut       => ''
+        DefaultSignKey      => '',
+        UnlockTimeOut       => '',
         FollowUpLock        => 1,
         ParentQueueID       => '',
     );
