@@ -50,6 +50,9 @@ sub Run {
         'Znuny-NoteToLinkedTicket',
         'Znuny4OTRS-NoteToLinkedTicket',
         'Znuny4OTRS-UserMaxArticlesPerPage',
+        'Znuny-BugfixFormInput',
+        'Znuny-DynamicFieldWebserviceTicketIDPayload',
+        'Znuny-RichTextEditorLinkFix',
     );
 
     PACKAGENAME:
