@@ -747,7 +747,7 @@ CREATE TABLE time_accounting (
 CREATE TABLE standard_template (
     id INTEGER NOT NULL AUTO_INCREMENT,
     name VARCHAR (200) NOT NULL,
-    text TEXT NULL,
+    text LONGTEXT NULL,
     content_type VARCHAR (250) NULL,
     template_type VARCHAR (100) NOT NULL DEFAULT 'Answer',
     comments VARCHAR (250) NULL,
@@ -997,7 +997,7 @@ CREATE TABLE customer_company (
 #  create table customer_user_customer
 # ----------------------------------------------------------
 CREATE TABLE customer_user_customer (
-    user_id VARCHAR (100) NOT NULL,
+    user_id VARCHAR (200) NOT NULL,
     customer_id VARCHAR (150) NOT NULL,
     create_time DATETIME NOT NULL,
     create_by INTEGER NOT NULL,
@@ -1045,8 +1045,8 @@ CREATE TABLE postmaster_filter (
 # ----------------------------------------------------------
 CREATE TABLE generic_agent_jobs (
     job_name VARCHAR (200) NOT NULL,
-    job_key VARCHAR (200) NOT NULL,
-    job_value VARCHAR (200) NULL,
+    job_key VARCHAR (255) NOT NULL,
+    job_value TEXT NULL,
     INDEX generic_agent_jobs_job_name (job_name)
 );
 # ----------------------------------------------------------
@@ -1106,7 +1106,7 @@ CREATE TABLE notification_event_message (
     id INTEGER NOT NULL AUTO_INCREMENT,
     notification_id INTEGER NOT NULL,
     subject VARCHAR (200) NOT NULL,
-    text TEXT NOT NULL,
+    text LONGTEXT NOT NULL,
     content_type VARCHAR (250) NOT NULL,
     language VARCHAR (60) NOT NULL,
     PRIMARY KEY(id),
@@ -1714,7 +1714,7 @@ CREATE TABLE calendar_appointment (
 CREATE TABLE calendar_appointment_plugin (
     id INTEGER NOT NULL AUTO_INCREMENT,
     dbcrud_uuid VARCHAR (36) NULL,
-    appointment_id SMALLINT NOT NULL,
+    appointment_id BIGINT NOT NULL,
     plugin_key TEXT NOT NULL,
     config MEDIUMTEXT NULL,
     create_time DATETIME NOT NULL,
@@ -1853,7 +1853,7 @@ CREATE TABLE smime_keys (
     key_hash VARCHAR (8) NOT NULL,
     key_type VARCHAR (255) NOT NULL,
     file_name VARCHAR (255) NOT NULL,
-    email_address VARCHAR (255) NULL,
+    email_address MEDIUMTEXT NULL,
     expiration_date DATETIME NULL,
     fingerprint VARCHAR (59) NULL,
     subject MEDIUMTEXT NULL,
