@@ -1798,7 +1798,7 @@ CREATE TABLE customer_company (
 --  create table customer_user_customer
 -- ----------------------------------------------------------
 CREATE TABLE customer_user_customer (
-    user_id VARCHAR (100) NOT NULL,
+    user_id VARCHAR (200) NOT NULL,
     customer_id VARCHAR (150) NOT NULL,
     create_time timestamp(0) NOT NULL,
     create_by INTEGER NOT NULL,
@@ -1876,8 +1876,8 @@ END$$;
 -- ----------------------------------------------------------
 CREATE TABLE generic_agent_jobs (
     job_name VARCHAR (200) NOT NULL,
-    job_key VARCHAR (200) NOT NULL,
-    job_value VARCHAR (200) NULL
+    job_key VARCHAR (255) NOT NULL,
+    job_value VARCHAR (3800) NULL
 );
 DO $$
 BEGIN
@@ -1967,7 +1967,7 @@ CREATE TABLE notification_event_message (
     id serial NOT NULL,
     notification_id INTEGER NOT NULL,
     subject VARCHAR (200) NOT NULL,
-    text VARCHAR (4000) NOT NULL,
+    text VARCHAR NOT NULL,
     content_type VARCHAR (250) NOT NULL,
     language VARCHAR (60) NOT NULL,
     PRIMARY KEY(id),
@@ -2855,7 +2855,7 @@ CREATE TABLE calendar_appointment (
 CREATE TABLE calendar_appointment_plugin (
     id serial NOT NULL,
     dbcrud_uuid VARCHAR (36) NULL,
-    appointment_id SMALLINT NOT NULL,
+    appointment_id BIGINT NOT NULL,
     plugin_key VARCHAR (1000) NOT NULL,
     config VARCHAR NULL,
     create_time timestamp(0) NOT NULL,
@@ -3144,7 +3144,7 @@ CREATE TABLE smime_keys (
     key_hash VARCHAR (8) NOT NULL,
     key_type VARCHAR (255) NOT NULL,
     file_name VARCHAR (255) NOT NULL,
-    email_address VARCHAR (255) NULL,
+    email_address VARCHAR NULL,
     expiration_date timestamp(0) NULL,
     fingerprint VARCHAR (59) NULL,
     subject VARCHAR NULL,
